@@ -3,6 +3,7 @@
 #include "util/edidHelper.h"
 #include "util/stringUtils.h"
 
+#ifdef __linux__
 #include <dirent.h>
 
 static const char* drmParseSysfs(FFDisplayServerResult* result)
@@ -36,7 +37,7 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
             continue;
         }
 
-        unsigned width = 0, height = 0;
+        unsigned width = 0, height = 0, physicalWidth = 0, physicalHeight = 0;
         double refreshRate = 0;
         FF_STRBUF_AUTO_DESTROY name = ffStrbufCreate();
 
@@ -48,6 +49,7 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
         {
             ffEdidGetName(edidData, &name);
             ffEdidGetPreferredResolutionAndRefreshRate(edidData, &width, &height, &refreshRate);
+            ffEdidGetPhysicalSize(edidData, &physicalWidth, &physicalHeight);
         }
         else
         {
@@ -77,7 +79,9 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
             &name,
             FF_DISPLAY_TYPE_UNKNOWN,
             false,
-            0
+            0,
+            physicalWidth,
+            physicalHeight
         );
 
         ffStrbufSubstrBefore(&drmDir, drmDirLength);
@@ -85,6 +89,7 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
 
     return NULL;
 }
+#endif
 
 #ifdef FF_HAVE_DRM
 
@@ -337,12 +342,14 @@ static const char* drmConnectLibdrm(FFDisplayServerResult* result)
                     0,
                     0,
                     &name,
-                    conn->connector_type == DRM_MODE_CONNECTOR_eDP
+                    conn->connector_type == DRM_MODE_CONNECTOR_eDP || conn->connector_type == DRM_MODE_CONNECTOR_LVDS
                         ? FF_DISPLAY_TYPE_BUILTIN
-                        : conn->connector_type == DRM_MODE_CONNECTOR_HDMIA || conn->connector_type == DRM_MODE_CONNECTOR_HDMIB
+                        : conn->connector_type == DRM_MODE_CONNECTOR_HDMIA || conn->connector_type == DRM_MODE_CONNECTOR_HDMIB || conn->connector_type == DRM_MODE_CONNECTOR_DisplayPort
                             ? FF_DISPLAY_TYPE_EXTERNAL : FF_DISPLAY_TYPE_UNKNOWN,
                     false,
-                    conn->connector_id
+                    conn->connector_id,
+                    conn->mmWidth,
+                    conn->mmHeight
                 );
             }
 
@@ -369,5 +376,7 @@ void ffdsConnectDrm(FFDisplayServerResult* result)
     }
     #endif
 
+    #ifdef __linux__
     drmParseSysfs(result);
+    #endif
 }
