@@ -12,6 +12,7 @@
 #include "modules/camera/camera.h"
 #include "modules/chassis/chassis.h"
 #include "modules/cpu/cpu.h"
+#include "modules/cpucache/cpucache.h"
 #include "modules/cpuusage/cpuusage.h"
 #include "modules/command/command.h"
 #include "modules/colors/colors.h"
@@ -22,6 +23,7 @@
 #include "modules/diskio/diskio.h"
 #include "modules/display/display.h"
 #include "modules/de/de.h"
+#include "modules/dns/dns.h"
 #include "modules/editor/editor.h"
 #include "modules/font/font.h"
 #include "modules/gamepad/gamepad.h"
