@@ -61,17 +61,7 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
         else if (ffStrEqualsIgnCase(key, "brightColor"))
             options->brightColor = yyjson_get_bool(val);
         else if (ffStrEqualsIgnCase(key, "binaryPrefix"))
-        {
-            int value;
-            const char* error = ffJsonConfigParseEnum(val, &value, (FFKeyValuePair[]) {
-                { "iec", FF_BINARY_PREFIX_TYPE_IEC },
-                { "si", FF_BINARY_PREFIX_TYPE_SI },
-                { "jedec", FF_BINARY_PREFIX_TYPE_JEDEC },
-                {},
-            });
-            if (error) return error;
-            options->binaryPrefixType = (FFBinaryPrefixType) value;
-        }
+            return "`display.binaryPrefix` has been renamed to `display.size.binaryPrefix`. Sorry for another break change.";
         else if (ffStrEqualsIgnCase(key, "size"))
         {
             if (!yyjson_is_obj(val))
@@ -97,6 +87,20 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
                 options->sizeMaxPrefix = (uint8_t) value;
             }
 
+            yyjson_val* binaryPrefix = yyjson_obj_get(val, "binaryPrefix");
+            if (binaryPrefix)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(binaryPrefix, &value, (FFKeyValuePair[]) {
+                    { "iec", FF_SIZE_BINARY_PREFIX_TYPE_IEC },
+                    { "si", FF_SIZE_BINARY_PREFIX_TYPE_SI },
+                    { "jedec", FF_SIZE_BINARY_PREFIX_TYPE_JEDEC },
+                    {},
+                });
+                if (error) return error;
+                options->sizeBinaryPrefix = (FFSizeBinaryPrefixType) value;
+            }
+
             yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
             if (ndigits) options->sizeNdigits = (uint8_t) yyjson_get_uint(ndigits);
         }
@@ -199,8 +203,23 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
             options->noBuffer = yyjson_get_bool(val);
         else if (ffStrEqualsIgnCase(key, "keyWidth"))
             options->keyWidth = (uint32_t) yyjson_get_uint(val);
-        else if (ffStrEqualsIgnCase(key, "tsVersion"))
-            options->tsVersion = yyjson_get_bool(val);
+        else if (ffStrEqualsIgnCase(key, "constants"))
+        {
+            if (!yyjson_is_arr(val))
+                return "display.constants must be an array";
+            yyjson_val* item;
+            size_t idx, max;
+            yyjson_arr_foreach(val, idx, max, item)
+                ffStrbufInitS(ffListAdd(&options->constants), yyjson_get_str(item));
+        }
+        else if (ffStrEqualsIgnCase(key, "freq"))
+        {
+            if (!yyjson_is_obj(val))
+                return "display.freq must be an object";
+
+            yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
+            if (ndigits) options->freqNdigits = (int8_t) yyjson_get_int(ndigits);
+        }
         else
             return "Unknown display property";
     }
@@ -273,29 +292,40 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
         options->brightColor = ffOptionParseBoolean(value);
     else if(ffStrEqualsIgnCase(key, "--binary-prefix"))
     {
-        options->binaryPrefixType = (FFBinaryPrefixType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
-            { "iec", FF_BINARY_PREFIX_TYPE_IEC },
-            { "si", FF_BINARY_PREFIX_TYPE_SI },
-            { "jedec", FF_BINARY_PREFIX_TYPE_JEDEC },
-            {}
-        });
+        fprintf(stderr, "--binary-prefix has been renamed to --size-binary-prefix\n");
+        exit(477);
     }
-    else if(ffStrEqualsIgnCase(key, "--size-ndigits"))
-        options->sizeNdigits = (uint8_t) ffOptionParseUInt32(key, value);
-    else if(ffStrEqualsIgnCase(key, "--size-max-prefix"))
+    else if(ffStrStartsWithIgnCase(key, "--size-"))
     {
-        options->sizeMaxPrefix = (uint8_t) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
-            { "B", 0 },
-            { "kB", 1 },
-            { "MB", 2 },
-            { "GB", 3 },
-            { "TB", 4 },
-            { "PB", 5 },
-            { "EB", 6 },
-            { "ZB", 7 },
-            { "YB", 8 },
-            {}
-        });
+        const char* subkey = key + strlen("--size-");
+        if (ffStrEqualsIgnCase(subkey, "binary-prefix"))
+        {
+            options->sizeBinaryPrefix = (FFSizeBinaryPrefixType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "iec", FF_SIZE_BINARY_PREFIX_TYPE_IEC },
+                { "si", FF_SIZE_BINARY_PREFIX_TYPE_SI },
+                { "jedec", FF_SIZE_BINARY_PREFIX_TYPE_JEDEC },
+                {}
+            });
+        }
+        else if (ffStrEqualsIgnCase(subkey, "ndigits"))
+            options->sizeNdigits = (uint8_t) ffOptionParseUInt32(key, value);
+        else if (ffStrEqualsIgnCase(subkey, "max-prefix"))
+        {
+            options->sizeMaxPrefix = (uint8_t) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "B", 0 },
+                { "kB", 1 },
+                { "MB", 2 },
+                { "GB", 3 },
+                { "TB", 4 },
+                { "PB", 5 },
+                { "EB", 6 },
+                { "ZB", 7 },
+                { "YB", 8 },
+                {}
+            });
+        }
+        else
+            return false;
     }
     else if(ffStrStartsWithIgnCase(key, "--temp-"))
     {
@@ -357,8 +387,12 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
         else
             return false;
     }
-    else if(ffStrEqualsIgnCase(key, "--ts-version"))
-        options->tsVersion = ffOptionParseBoolean(value);
+    else if(ffStrStartsWithIgnCase(key, "--freq-"))
+    {
+        const char* subkey = key + strlen("--freq-");
+        if(ffStrEqualsIgnCase(subkey, "ndigits"))
+            options->freqNdigits = (int8_t) ffOptionParseInt32(key, value);
+    }
     else
         return false;
     return true;
@@ -383,7 +417,7 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     #endif
 
     options->hideCursor = false;
-    options->binaryPrefixType = FF_BINARY_PREFIX_TYPE_IEC;
+    options->sizeBinaryPrefix = FF_SIZE_BINARY_PREFIX_TYPE_IEC;
     options->sizeNdigits = 2;
     options->sizeMaxPrefix = UINT8_MAX;
     options->stat = false;
@@ -406,8 +440,9 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     ffStrbufInitStatic(&options->percentColorGreen, FF_COLOR_FG_GREEN);
     ffStrbufInitStatic(&options->percentColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
     ffStrbufInitStatic(&options->percentColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
+    options->freqNdigits = 2;
 
-    options->tsVersion = true;
+    ffListInit(&options->constants, sizeof(FFstrbuf));
 }
 
 void ffOptionsDestroyDisplay(FFOptionsDisplay* options)
@@ -419,6 +454,9 @@ void ffOptionsDestroyDisplay(FFOptionsDisplay* options)
     ffStrbufDestroy(&options->keyValueSeparator);
     ffStrbufDestroy(&options->barCharElapsed);
     ffStrbufDestroy(&options->barCharTotal);
+    FF_LIST_FOR_EACH(FFstrbuf, item, options->constants)
+        ffStrbufDestroy(item);
+    ffListDestroy(&options->constants);
 }
 
 void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_doc* doc)
@@ -468,23 +506,6 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
     if (options->brightColor != defaultOptions.brightColor)
         yyjson_mut_obj_add_bool(doc, obj, "brightColor", options->brightColor);
 
-    if (options->binaryPrefixType != defaultOptions.binaryPrefixType)
-    {
-        switch (options->binaryPrefixType)
-        {
-            case FF_BINARY_PREFIX_TYPE_IEC:
-                yyjson_mut_obj_add_str(doc, obj, "binaryPrefix", "iec");
-                break;
-            case FF_BINARY_PREFIX_TYPE_SI:
-                yyjson_mut_obj_add_str(doc, obj, "binaryPrefix", "si");
-                break;
-            case FF_BINARY_PREFIX_TYPE_JEDEC:
-                yyjson_mut_obj_add_str(doc, obj, "binaryPrefix", "jedec");
-                break;
-
-        }
-    }
-
     {
         yyjson_mut_val* size = yyjson_mut_obj(doc);
         if (options->sizeNdigits != defaultOptions.sizeNdigits)
@@ -503,6 +524,21 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
                 "YB",
             })[options->sizeMaxPrefix]);
         }
+        if (options->sizeBinaryPrefix != defaultOptions.sizeBinaryPrefix)
+        {
+            switch (options->sizeBinaryPrefix)
+            {
+                case FF_SIZE_BINARY_PREFIX_TYPE_IEC:
+                    yyjson_mut_obj_add_str(doc, size, "binaryPrefix", "iec");
+                    break;
+                case FF_SIZE_BINARY_PREFIX_TYPE_SI:
+                    yyjson_mut_obj_add_str(doc, size, "binaryPrefix", "si");
+                    break;
+                case FF_SIZE_BINARY_PREFIX_TYPE_JEDEC:
+                    yyjson_mut_obj_add_str(doc, size, "binaryPrefix", "jedec");
+                    break;
+            }
+        }
         if (yyjson_mut_obj_size(size) > 0)
             yyjson_mut_obj_add_val(doc, obj, "size", size);
     }
@@ -585,6 +621,14 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
     if (options->keyWidth != defaultOptions.keyWidth)
         yyjson_mut_obj_add_uint(doc, obj, "keyWidth", options->keyWidth);
 
+    {
+        yyjson_mut_val* freq = yyjson_mut_obj(doc);
+        if (options->freqNdigits != defaultOptions.freqNdigits)
+            yyjson_mut_obj_add_int(doc, freq, "ndigits", options->freqNdigits);
+        if (yyjson_mut_obj_size(freq) > 0)
+            yyjson_mut_obj_add_val(doc, obj, "freq", freq);
+    }
+
     if (yyjson_mut_obj_size(obj) > 0)
         yyjson_mut_obj_add_val(doc, doc->root, "display", obj);
 }
